#
# spec file for package python-faulthandler
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-faulthandler
Version:        3.1
Release:        2.1
Summary:        Display the Python traceback on a crash
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/vstinner/faulthandler
Source:         https://files.pythonhosted.org/packages/source/f/faulthandler/faulthandler-%{version}.tar.gz
Patch0:         skip-test.patch
BuildRequires:  python-devel
BuildRequires:  python-rpm-macros
BuildRequires:  python-setuptools
Provides:       python2-faulthandler = %{version}

%description
Fault handler for SIGSEGV, SIGFPE, SIGABRT, SIGBUS and SIGILL signals: display
the Python traceback and restore the previous handler. Allocate an alternate
stack for this handler, if sigaltstack() is available, to be able to allocate
memory on the stack, even on stack overflow (not available on Windows).

Import the module and call faulthandler.enable() to enable the fault handler.

%prep
%setup -q -n faulthandler-%{version}
%patch0 -p1

%build
%python2_build

%install
%python2_install

%check
PYTHONPATH=%{buildroot}%{python_sitearch} python tests.py --verbose

%files
%license COPYING
%doc AUTHORS README.rst
%{python_sitearch}/faulthandler*

%changelog
* Tue Mar 26 2019 tchvatal@suse.com
- Add patch to skip one test that fails in OBS:
  * skip-test.patch
* Tue Mar 26 2019 tchvatal@suse.com
- Update to 3.1:
  * Project moved from https://github.com/haypo/faulthandler to https://github.com/vstinner/faulthandler
  * Fix tests: accept "python2" and "python2.7" thread name in tests
  * Fix tests on Python 2.6.
  * On Windows, faulthandler.register() now also installs an handler for Windows exceptions.
  * Add support for the PYTHONFAULTHANDLER environment variable. Patch written by Ionel Cristian Mărieș.
  * Issue #23433: Fix undefined behaviour in faulthandler._stack_overflow(): don't compare pointers, use the Py_uintptr_t type instead of void*. It fixes test_faulthandler on Fedora 22 which now uses GCC 5.
  * The write() function used to write the traceback is now retried when it is interrupted by a signal.
  * Issue #23566: enable(), register(), dump_traceback() and dump_traceback_later() functions now accept file descriptors. Patch by Wei Wu.
  * Drop support and Python 2.5, 2.6, 3.1 and 3.2: only support Python 2.7. No Linux distribution use these versions anymore, so it becomes difficult to test these versions.
  * Add tox.ini to run tests with tox: it creates a virtual environment, compile and install faulthandler, and run unit tests.
  * Add Travis YAML configuration.
- Run tests
* Wed May  2 2018 tchvatal@suse.com
- Fix url
* Fri Nov 10 2017 toddrme2178@gmail.com
- Provide python2-faulthandler for compatibility with singlespec
  macros
* Sat Aug 22 2015 i@marguerite.su
- disable tests
  * too time-consuming and fails on TW
* Sun Aug 16 2015 i@marguerite.su
- update to version 2.4
  * no changelog
* Thu Aug  1 2013 hpj@urpla.net
- clean up spec file
* Wed Jul 31 2013 hpj@urpla.net
- updated to version 2.2
  * Rename dump_tracebacks_later() to dump_traceback_later():
    use the same API than the faulthandler module of Python 3.3
  * Fix handling of errno variable in the handler of user signals
  * Fix the handler of user signals: chain the previous signal
    handler even if getting the current thread state failed
- updated to version 2.1
  * Add an optional chain argument to faulthandler.register()
  * Fix faulthandler._sigsegv() for Clang 3.0
  * Fix compilation on Visual Studio
- tests enabled
* Fri Aug 26 2011 hpj@urpla.net
- version 2.0: initial build
